GCC PARALLEL_MAKE changed
Hi,
We noticed that the GCC parallel make flag (PARALLEL_MAKE, located in "meta/recipes-devtools/gcc/gcc-cross-canadian_4.?.bb") got changed from "-j 32" to simply nothing.
We are wondering what was the reason for this change, which seems to have been made somewhere before the fall of 2012, while the GCC was around version 4.6 or earlier (for each we dont have the repository to track down the change).
After several builds where the compile time for GCC got measured, I can say that this flag indeed reduces the build time, when it is put at "-j 32" (using a proper build machine). In average the build time frame was reduced by 18%.
Much appreciated any thoughts on this, I know that it has been a while since this change happen.
Thank you very much,
Vali
Vali
Quoted 10 lines · Vali Cobelea
Hi,
We noticed that the GCC parallel make flag (
PARALLEL_MAKE, located in "meta/recipes-devtools/gcc/gcc-cross-canadian_4.?.bb") got changed from "-j 32" to simply nothing.
We are wondering what was the reason for this change, which seems to have been made somewhere before the fall of 2012, while the GCC was around version 4.6 or earlier (for each we dont have the repository to track down the change).After several builds where the compile time for GCC got measured, I can say that this flag indeed reduces the build time, when it is put at "-j 32" (using a proper build machine). In average the build time frame was reduced by 18%.
Much appreciated any thoughts on this, I know that it has been a while since this change happen.
There were race conditions happening with the build. I have not verified if they have been fixed. However you could try remove
PARALLEL_MAKE = ""
from recipe and then it should respect the global -j value and see if this builds consistently. If it does propose a patch to remove it
Quoted 6 lines
Thank you very much,
Vali
_______________________________________________
Openembedded-core mailing list
[email protected]
http://lists.openembedded.org/mailman/listinfo/openembedded-core